#include "library.h"

namespace py = pybind11;

void define_replay_unit(py::module & m)
{
    py::class_<UnitInformation>(m, "ReplayUnit")
        .def_property_readonly("unit_type", &Unit::getType, "The :class:`library.UnitType` of the unit")
        .def_property_readonly("position", &Unit::getPosition, "The :class:`library.Point2D` of the unit")
        .def_property_readonly("tile_position", &Unit::getTilePosition, "The :class:`library.Point2DI` of the unit")
        .def_property_readonly("hit_points", &Unit::getHitPoints)
        .def_property_readonly("shields", &Unit::getShields)
        .def_property_readonly("energy", &Unit::getEnergy)
        .def_property_readonly("player", &Unit::getPlayer)
        .def_property_readonly("id", &Unit::getID)
        .def_property_readonly("build_percentage", &Unit::getBuildPercentage)
        .def_property_readonly("weapon_cooldown", &Unit::getWeaponCooldown)
        .def_property_readonly("is_completed", &Unit::isCompleted)
        .def_property_readonly("is_being_constructed", &Unit::isBeingConstructed)
        .def_property_readonly("is_cloaked", &Unit::isCloaked)
        .def_property_readonly("is_flying", &Unit::isFlying)
        .def_property_readonly("buffs", &Unit::buffs)
        .def_property_readonly("is_alive", &Unit::isAlive)
        .def_property_readonly("is_powered", &Unit::isPowered)
        .def_property_readonly("is_idle", &Unit::isIdle)
        .def_property_readonly("is_burrowed", &Unit::isBurrowed)
        .def_property_readonly("is_valid", &Unit::isValid)
        .def_property_readonly("is_training", &Unit::isTraining)
        .def_property_readonly("is_blip", &Unit::isBlip)
        .def_property_readonly("target", &Unit::getTarget)
        .def_property_readonly("has_target", &Unit::hasTarget)
        .def_property_readonly("max_hit_points", &Unit::getMaxHitPoints)
        .def_property_readonly("progress", &Unit::getProgress)
        .def_property_readonly("current_ability_id", &Unit::getCurrentAbilityID, "The AbilityID of currently used ability")
        .def_property_readonly("facing", &Unit::getFacing)
        .def_property_readonly("radius", &Unit::getRadius)
        .def_property_readonly("is_carrying_minerals", &Unit::isCarryingMinerals)
        .def("__hash__", [](const Unit & unit) { return std::hash<const sc2::Unit *>{}(unit.getUnitPtr()); })
        .def(py::self == py::self)
        .def("__repr__", [](const Unit & unit) { return "<Unit of type: '" + unit.getType().getName() + "'>"; });
}
